# coding: utf-8

"""
    Mux API

    Mux is how developers build online video. This API encompasses both Mux Video and Mux Data functionality to help you build your video-related projects better and faster than ever before.  # noqa: E501

    The version of the OpenAPI document: v1
    Contact: devex@mux.com
    Generated by: https://openapi-generator.tech
"""


import inspect
import pprint
import re  # noqa: F401
import six

from mux_python.configuration import Configuration


class InputSettings(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'url': 'str',
        'overlay_settings': 'InputSettingsOverlaySettings',
        'start_time': 'float',
        'end_time': 'float',
        'type': 'str',
        'text_type': 'str',
        'language_code': 'str',
        'name': 'str',
        'closed_captions': 'bool',
        'passthrough': 'str'
    }

    attribute_map = {
        'url': 'url',
        'overlay_settings': 'overlay_settings',
        'start_time': 'start_time',
        'end_time': 'end_time',
        'type': 'type',
        'text_type': 'text_type',
        'language_code': 'language_code',
        'name': 'name',
        'closed_captions': 'closed_captions',
        'passthrough': 'passthrough'
    }

    def __init__(self, url=None, overlay_settings=None, start_time=None, end_time=None, type=None, text_type=None, language_code=None, name=None, closed_captions=None, passthrough=None, local_vars_configuration=None):  # noqa: E501
        """InputSettings - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default_copy()
        self.local_vars_configuration = local_vars_configuration

        self._url = None
        self._overlay_settings = None
        self._start_time = None
        self._end_time = None
        self._type = None
        self._text_type = None
        self._language_code = None
        self._name = None
        self._closed_captions = None
        self._passthrough = None
        self.discriminator = None

        if url is not None:
            self.url = url
        if overlay_settings is not None:
            self.overlay_settings = overlay_settings
        if start_time is not None:
            self.start_time = start_time
        if end_time is not None:
            self.end_time = end_time
        if type is not None:
            self.type = type
        if text_type is not None:
            self.text_type = text_type
        if language_code is not None:
            self.language_code = language_code
        if name is not None:
            self.name = name
        if closed_captions is not None:
            self.closed_captions = closed_captions
        if passthrough is not None:
            self.passthrough = passthrough

    @property
    def url(self):
        """Gets the url of this InputSettings.  # noqa: E501

        The web address of the file that Mux should download and use. * For subtitles text tracks, the url is the location of subtitle/captions file. Mux supports [SubRip Text (SRT)](https://en.wikipedia.org/wiki/SubRip) and [Web Video Text Tracks](https://www.w3.org/TR/webvtt1/) format for ingesting Subtitles and Closed Captions. * For Watermarking or Overlay, the url is the location of the watermark image. * When creating clips from existing Mux assets, the url is defined with `mux://assets/{asset_id}` template where `asset_id` is the Asset Identifier for creating the clip from.   # noqa: E501

        :return: The url of this InputSettings.  # noqa: E501
        :rtype: str
        """
        return self._url

    @url.setter
    def url(self, url):
        """Sets the url of this InputSettings.

        The web address of the file that Mux should download and use. * For subtitles text tracks, the url is the location of subtitle/captions file. Mux supports [SubRip Text (SRT)](https://en.wikipedia.org/wiki/SubRip) and [Web Video Text Tracks](https://www.w3.org/TR/webvtt1/) format for ingesting Subtitles and Closed Captions. * For Watermarking or Overlay, the url is the location of the watermark image. * When creating clips from existing Mux assets, the url is defined with `mux://assets/{asset_id}` template where `asset_id` is the Asset Identifier for creating the clip from.   # noqa: E501

        :param url: The url of this InputSettings.  # noqa: E501
        :type url: str
        """

        self._url = url

    @property
    def overlay_settings(self):
        """Gets the overlay_settings of this InputSettings.  # noqa: E501


        :return: The overlay_settings of this InputSettings.  # noqa: E501
        :rtype: InputSettingsOverlaySettings
        """
        return self._overlay_settings

    @overlay_settings.setter
    def overlay_settings(self, overlay_settings):
        """Sets the overlay_settings of this InputSettings.


        :param overlay_settings: The overlay_settings of this InputSettings.  # noqa: E501
        :type overlay_settings: InputSettingsOverlaySettings
        """

        self._overlay_settings = overlay_settings

    @property
    def start_time(self):
        """Gets the start_time of this InputSettings.  # noqa: E501

        The time offset in seconds from the beginning of the video indicating the clip's starting marker. The default value is 0 when not included. This parameter is only applicable for creating clips when `input.url` has `mux://assets/{asset_id}` format.  # noqa: E501

        :return: The start_time of this InputSettings.  # noqa: E501
        :rtype: float
        """
        return self._start_time

    @start_time.setter
    def start_time(self, start_time):
        """Sets the start_time of this InputSettings.

        The time offset in seconds from the beginning of the video indicating the clip's starting marker. The default value is 0 when not included. This parameter is only applicable for creating clips when `input.url` has `mux://assets/{asset_id}` format.  # noqa: E501

        :param start_time: The start_time of this InputSettings.  # noqa: E501
        :type start_time: float
        """

        self._start_time = start_time

    @property
    def end_time(self):
        """Gets the end_time of this InputSettings.  # noqa: E501

        The time offset in seconds from the beginning of the video, indicating the clip's ending marker. The default value is the duration of the video when not included. This parameter is only applicable for creating clips when `input.url` has `mux://assets/{asset_id}` format.  # noqa: E501

        :return: The end_time of this InputSettings.  # noqa: E501
        :rtype: float
        """
        return self._end_time

    @end_time.setter
    def end_time(self, end_time):
        """Sets the end_time of this InputSettings.

        The time offset in seconds from the beginning of the video, indicating the clip's ending marker. The default value is the duration of the video when not included. This parameter is only applicable for creating clips when `input.url` has `mux://assets/{asset_id}` format.  # noqa: E501

        :param end_time: The end_time of this InputSettings.  # noqa: E501
        :type end_time: float
        """

        self._end_time = end_time

    @property
    def type(self):
        """Gets the type of this InputSettings.  # noqa: E501

        This parameter is required for the `text` track type.  # noqa: E501

        :return: The type of this InputSettings.  # noqa: E501
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this InputSettings.

        This parameter is required for the `text` track type.  # noqa: E501

        :param type: The type of this InputSettings.  # noqa: E501
        :type type: str
        """
        allowed_values = ["video", "audio", "text"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and type not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `type` ({0}), must be one of {1}"  # noqa: E501
                .format(type, allowed_values)
            )

        self._type = type

    @property
    def text_type(self):
        """Gets the text_type of this InputSettings.  # noqa: E501

        Type of text track. This parameter only supports subtitles value. For more information on Subtitles / Closed Captions, [see this blog post](https://mux.com/blog/subtitles-captions-webvtt-hls-and-those-magic-flags/). This parameter is required for `text` track type.  # noqa: E501

        :return: The text_type of this InputSettings.  # noqa: E501
        :rtype: str
        """
        return self._text_type

    @text_type.setter
    def text_type(self, text_type):
        """Sets the text_type of this InputSettings.

        Type of text track. This parameter only supports subtitles value. For more information on Subtitles / Closed Captions, [see this blog post](https://mux.com/blog/subtitles-captions-webvtt-hls-and-those-magic-flags/). This parameter is required for `text` track type.  # noqa: E501

        :param text_type: The text_type of this InputSettings.  # noqa: E501
        :type text_type: str
        """
        allowed_values = ["subtitles"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and text_type not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `text_type` ({0}), must be one of {1}"  # noqa: E501
                .format(text_type, allowed_values)
            )

        self._text_type = text_type

    @property
    def language_code(self):
        """Gets the language_code of this InputSettings.  # noqa: E501

        The language code value must be a valid [BCP 47](https://tools.ietf.org/html/bcp47) specification compliant value. For example, en for English or en-US for the US version of English. This parameter is required for text type and subtitles text type track.  # noqa: E501

        :return: The language_code of this InputSettings.  # noqa: E501
        :rtype: str
        """
        return self._language_code

    @language_code.setter
    def language_code(self, language_code):
        """Sets the language_code of this InputSettings.

        The language code value must be a valid [BCP 47](https://tools.ietf.org/html/bcp47) specification compliant value. For example, en for English or en-US for the US version of English. This parameter is required for text type and subtitles text type track.  # noqa: E501

        :param language_code: The language_code of this InputSettings.  # noqa: E501
        :type language_code: str
        """

        self._language_code = language_code

    @property
    def name(self):
        """Gets the name of this InputSettings.  # noqa: E501

        The name of the track containing a human-readable description. This value must be unique across all text type and subtitles `text` type tracks. The hls manifest will associate a subtitle text track with this value. For example, the value should be \"English\" for subtitles text track with language_code as en. This optional parameter should be used only for `text` type and subtitles `text` type track. If this parameter is not included, Mux will auto-populate based on the `input[].language_code` value.  # noqa: E501

        :return: The name of this InputSettings.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this InputSettings.

        The name of the track containing a human-readable description. This value must be unique across all text type and subtitles `text` type tracks. The hls manifest will associate a subtitle text track with this value. For example, the value should be \"English\" for subtitles text track with language_code as en. This optional parameter should be used only for `text` type and subtitles `text` type track. If this parameter is not included, Mux will auto-populate based on the `input[].language_code` value.  # noqa: E501

        :param name: The name of this InputSettings.  # noqa: E501
        :type name: str
        """

        self._name = name

    @property
    def closed_captions(self):
        """Gets the closed_captions of this InputSettings.  # noqa: E501

        Indicates the track provides Subtitles for the Deaf or Hard-of-hearing (SDH). This optional parameter should be used for `text` type and subtitles `text` type tracks.  # noqa: E501

        :return: The closed_captions of this InputSettings.  # noqa: E501
        :rtype: bool
        """
        return self._closed_captions

    @closed_captions.setter
    def closed_captions(self, closed_captions):
        """Sets the closed_captions of this InputSettings.

        Indicates the track provides Subtitles for the Deaf or Hard-of-hearing (SDH). This optional parameter should be used for `text` type and subtitles `text` type tracks.  # noqa: E501

        :param closed_captions: The closed_captions of this InputSettings.  # noqa: E501
        :type closed_captions: bool
        """

        self._closed_captions = closed_captions

    @property
    def passthrough(self):
        """Gets the passthrough of this InputSettings.  # noqa: E501

        This optional parameter should be used for `text` type and subtitles `text` type tracks.  # noqa: E501

        :return: The passthrough of this InputSettings.  # noqa: E501
        :rtype: str
        """
        return self._passthrough

    @passthrough.setter
    def passthrough(self, passthrough):
        """Sets the passthrough of this InputSettings.

        This optional parameter should be used for `text` type and subtitles `text` type tracks.  # noqa: E501

        :param passthrough: The passthrough of this InputSettings.  # noqa: E501
        :type passthrough: str
        """

        self._passthrough = passthrough

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = inspect.getargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: convert(x),
                    value
                ))
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], convert(item[1])),
                    value.items()
                ))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, InputSettings):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, InputSettings):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Mux API

    Mux is how developers build online video. This API encompasses both Mux Video and Mux Data functionality to help you build your video-related projects better and faster than ever before.  # noqa: E501

    The version of the OpenAPI document: v1
    Contact: devex@mux.com
    Generated by: https://openapi-generator.tech
"""


import inspect
import pprint
import re  # noqa: F401
import six

from mux_python.configuration import Configuration


class SimulcastTarget(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'id': 'str',
        'passthrough': 'str',
        'status': 'str',
        'stream_key': 'str',
        'url': 'str'
    }

    attribute_map = {
        'id': 'id',
        'passthrough': 'passthrough',
        'status': 'status',
        'stream_key': 'stream_key',
        'url': 'url'
    }

    def __init__(self, id=None, passthrough=None, status=None, stream_key=None, url=None, local_vars_configuration=None):  # noqa: E501
        """SimulcastTarget - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default_copy()
        self.local_vars_configuration = local_vars_configuration

        self._id = None
        self._passthrough = None
        self._status = None
        self._stream_key = None
        self._url = None
        self.discriminator = None

        if id is not None:
            self.id = id
        if passthrough is not None:
            self.passthrough = passthrough
        if status is not None:
            self.status = status
        if stream_key is not None:
            self.stream_key = stream_key
        if url is not None:
            self.url = url

    @property
    def id(self):
        """Gets the id of this SimulcastTarget.  # noqa: E501

        ID of the Simulcast Target  # noqa: E501

        :return: The id of this SimulcastTarget.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this SimulcastTarget.

        ID of the Simulcast Target  # noqa: E501

        :param id: The id of this SimulcastTarget.  # noqa: E501
        :type id: str
        """

        self._id = id

    @property
    def passthrough(self):
        """Gets the passthrough of this SimulcastTarget.  # noqa: E501

        Arbitrary Metadata set when creating a simulcast target.  # noqa: E501

        :return: The passthrough of this SimulcastTarget.  # noqa: E501
        :rtype: str
        """
        return self._passthrough

    @passthrough.setter
    def passthrough(self, passthrough):
        """Sets the passthrough of this SimulcastTarget.

        Arbitrary Metadata set when creating a simulcast target.  # noqa: E501

        :param passthrough: The passthrough of this SimulcastTarget.  # noqa: E501
        :type passthrough: str
        """

        self._passthrough = passthrough

    @property
    def status(self):
        """Gets the status of this SimulcastTarget.  # noqa: E501

        The current status of the simulcast target. See Statuses below for detailed description.   * `idle`: Default status. When the parent live stream is in disconnected status, simulcast targets will be idle state.   * `starting`: The simulcast target transitions into this state when the parent live stream transition into connected state.   * `broadcasting`: The simulcast target has successfully connected to the third party live streaming service and is pushing video to that service.   * `errored`: The simulcast target encountered an error either while attempting to connect to the third party live streaming service, or mid-broadcasting. Compared to other errored statuses in the Mux Video API, a simulcast may transition back into the broadcasting state if a connection with the service can be re-established.   # noqa: E501

        :return: The status of this SimulcastTarget.  # noqa: E501
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this SimulcastTarget.

        The current status of the simulcast target. See Statuses below for detailed description.   * `idle`: Default status. When the parent live stream is in disconnected status, simulcast targets will be idle state.   * `starting`: The simulcast target transitions into this state when the parent live stream transition into connected state.   * `broadcasting`: The simulcast target has successfully connected to the third party live streaming service and is pushing video to that service.   * `errored`: The simulcast target encountered an error either while attempting to connect to the third party live streaming service, or mid-broadcasting. Compared to other errored statuses in the Mux Video API, a simulcast may transition back into the broadcasting state if a connection with the service can be re-established.   # noqa: E501

        :param status: The status of this SimulcastTarget.  # noqa: E501
        :type status: str
        """
        allowed_values = ["idle", "starting", "broadcasting", "errored"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and status not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `status` ({0}), must be one of {1}"  # noqa: E501
                .format(status, allowed_values)
            )

        self._status = status

    @property
    def stream_key(self):
        """Gets the stream_key of this SimulcastTarget.  # noqa: E501

        Stream Key represents an stream identifier for the third party live streaming service to simulcast the parent live stream too.  # noqa: E501

        :return: The stream_key of this SimulcastTarget.  # noqa: E501
        :rtype: str
        """
        return self._stream_key

    @stream_key.setter
    def stream_key(self, stream_key):
        """Sets the stream_key of this SimulcastTarget.

        Stream Key represents an stream identifier for the third party live streaming service to simulcast the parent live stream too.  # noqa: E501

        :param stream_key: The stream_key of this SimulcastTarget.  # noqa: E501
        :type stream_key: str
        """

        self._stream_key = stream_key

    @property
    def url(self):
        """Gets the url of this SimulcastTarget.  # noqa: E501

        RTMP hostname including the application name for the third party live streaming service.  # noqa: E501

        :return: The url of this SimulcastTarget.  # noqa: E501
        :rtype: str
        """
        return self._url

    @url.setter
    def url(self, url):
        """Sets the url of this SimulcastTarget.

        RTMP hostname including the application name for the third party live streaming service.  # noqa: E501

        :param url: The url of this SimulcastTarget.  # noqa: E501
        :type url: str
        """

        self._url = url

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = inspect.getargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: convert(x),
                    value
                ))
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], convert(item[1])),
                    value.items()
                ))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, SimulcastTarget):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, SimulcastTarget):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Mux API

    Mux is how developers build online video. This API encompasses both Mux Video and Mux Data functionality to help you build your video-related projects better and faster than ever before.  # noqa: E501

    The version of the OpenAPI document: v1
    Contact: devex@mux.com
    Generated by: https://openapi-generator.tech
"""


import inspect
import pprint
import re  # noqa: F401
import six

from mux_python.configuration import Configuration


class Asset(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'id': 'str',
        'created_at': 'str',
        'status': 'str',
        'duration': 'float',
        'max_stored_resolution': 'str',
        'max_stored_frame_rate': 'float',
        'aspect_ratio': 'str',
        'playback_ids': 'list[PlaybackID]',
        'tracks': 'list[Track]',
        'errors': 'AssetErrors',
        'per_title_encode': 'bool',
        'upload_id': 'str',
        'is_live': 'bool',
        'passthrough': 'str',
        'live_stream_id': 'str',
        'master': 'AssetMaster',
        'master_access': 'str',
        'mp4_support': 'str',
        'source_asset_id': 'str',
        'normalize_audio': 'bool',
        'static_renditions': 'AssetStaticRenditions',
        'recording_times': 'list[AssetRecordingTimes]',
        'non_standard_input_reasons': 'AssetNonStandardInputReasons',
        'test': 'bool'
    }

    attribute_map = {
        'id': 'id',
        'created_at': 'created_at',
        'status': 'status',
        'duration': 'duration',
        'max_stored_resolution': 'max_stored_resolution',
        'max_stored_frame_rate': 'max_stored_frame_rate',
        'aspect_ratio': 'aspect_ratio',
        'playback_ids': 'playback_ids',
        'tracks': 'tracks',
        'errors': 'errors',
        'per_title_encode': 'per_title_encode',
        'upload_id': 'upload_id',
        'is_live': 'is_live',
        'passthrough': 'passthrough',
        'live_stream_id': 'live_stream_id',
        'master': 'master',
        'master_access': 'master_access',
        'mp4_support': 'mp4_support',
        'source_asset_id': 'source_asset_id',
        'normalize_audio': 'normalize_audio',
        'static_renditions': 'static_renditions',
        'recording_times': 'recording_times',
        'non_standard_input_reasons': 'non_standard_input_reasons',
        'test': 'test'
    }

    def __init__(self, id=None, created_at=None, status=None, duration=None, max_stored_resolution=None, max_stored_frame_rate=None, aspect_ratio=None, playback_ids=None, tracks=None, errors=None, per_title_encode=None, upload_id=None, is_live=None, passthrough=None, live_stream_id=None, master=None, master_access='none', mp4_support='none', source_asset_id=None, normalize_audio=False, static_renditions=None, recording_times=None, non_standard_input_reasons=None, test=None, local_vars_configuration=None):  # noqa: E501
        """Asset - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default_copy()
        self.local_vars_configuration = local_vars_configuration

        self._id = None
        self._created_at = None
        self._status = None
        self._duration = None
        self._max_stored_resolution = None
        self._max_stored_frame_rate = None
        self._aspect_ratio = None
        self._playback_ids = None
        self._tracks = None
        self._errors = None
        self._per_title_encode = None
        self._upload_id = None
        self._is_live = None
        self._passthrough = None
        self._live_stream_id = None
        self._master = None
        self._master_access = None
        self._mp4_support = None
        self._source_asset_id = None
        self._normalize_audio = None
        self._static_renditions = None
        self._recording_times = None
        self._non_standard_input_reasons = None
        self._test = None
        self.discriminator = None

        if id is not None:
            self.id = id
        if created_at is not None:
            self.created_at = created_at
        if status is not None:
            self.status = status
        if duration is not None:
            self.duration = duration
        if max_stored_resolution is not None:
            self.max_stored_resolution = max_stored_resolution
        if max_stored_frame_rate is not None:
            self.max_stored_frame_rate = max_stored_frame_rate
        if aspect_ratio is not None:
            self.aspect_ratio = aspect_ratio
        if playback_ids is not None:
            self.playback_ids = playback_ids
        if tracks is not None:
            self.tracks = tracks
        if errors is not None:
            self.errors = errors
        if per_title_encode is not None:
            self.per_title_encode = per_title_encode
        if upload_id is not None:
            self.upload_id = upload_id
        if is_live is not None:
            self.is_live = is_live
        if passthrough is not None:
            self.passthrough = passthrough
        if live_stream_id is not None:
            self.live_stream_id = live_stream_id
        if master is not None:
            self.master = master
        if master_access is not None:
            self.master_access = master_access
        if mp4_support is not None:
            self.mp4_support = mp4_support
        if source_asset_id is not None:
            self.source_asset_id = source_asset_id
        if normalize_audio is not None:
            self.normalize_audio = normalize_audio
        if static_renditions is not None:
            self.static_renditions = static_renditions
        if recording_times is not None:
            self.recording_times = recording_times
        if non_standard_input_reasons is not None:
            self.non_standard_input_reasons = non_standard_input_reasons
        if test is not None:
            self.test = test

    @property
    def id(self):
        """Gets the id of this Asset.  # noqa: E501

        Unique identifier for the Asset. Max 255 characters.  # noqa: E501

        :return: The id of this Asset.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this Asset.

        Unique identifier for the Asset. Max 255 characters.  # noqa: E501

        :param id: The id of this Asset.  # noqa: E501
        :type id: str
        """

        self._id = id

    @property
    def created_at(self):
        """Gets the created_at of this Asset.  # noqa: E501

        Time the Asset was created, defined as a Unix timestamp (seconds since epoch).  # noqa: E501

        :return: The created_at of this Asset.  # noqa: E501
        :rtype: str
        """
        return self._created_at

    @created_at.setter
    def created_at(self, created_at):
        """Sets the created_at of this Asset.

        Time the Asset was created, defined as a Unix timestamp (seconds since epoch).  # noqa: E501

        :param created_at: The created_at of this Asset.  # noqa: E501
        :type created_at: str
        """

        self._created_at = created_at

    @property
    def status(self):
        """Gets the status of this Asset.  # noqa: E501

        The status of the asset.  # noqa: E501

        :return: The status of this Asset.  # noqa: E501
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this Asset.

        The status of the asset.  # noqa: E501

        :param status: The status of this Asset.  # noqa: E501
        :type status: str
        """
        allowed_values = ["preparing", "ready", "errored"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and status not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `status` ({0}), must be one of {1}"  # noqa: E501
                .format(status, allowed_values)
            )

        self._status = status

    @property
    def duration(self):
        """Gets the duration of this Asset.  # noqa: E501

        The duration of the asset in seconds (max duration for a single asset is 12 hours).  # noqa: E501

        :return: The duration of this Asset.  # noqa: E501
        :rtype: float
        """
        return self._duration

    @duration.setter
    def duration(self, duration):
        """Sets the duration of this Asset.

        The duration of the asset in seconds (max duration for a single asset is 12 hours).  # noqa: E501

        :param duration: The duration of this Asset.  # noqa: E501
        :type duration: float
        """

        self._duration = duration

    @property
    def max_stored_resolution(self):
        """Gets the max_stored_resolution of this Asset.  # noqa: E501

        The maximum resolution that has been stored for the asset. The asset may be delivered at lower resolutions depending on the device and bandwidth, however it cannot be delivered at a higher value than is stored.  # noqa: E501

        :return: The max_stored_resolution of this Asset.  # noqa: E501
        :rtype: str
        """
        return self._max_stored_resolution

    @max_stored_resolution.setter
    def max_stored_resolution(self, max_stored_resolution):
        """Sets the max_stored_resolution of this Asset.

        The maximum resolution that has been stored for the asset. The asset may be delivered at lower resolutions depending on the device and bandwidth, however it cannot be delivered at a higher value than is stored.  # noqa: E501

        :param max_stored_resolution: The max_stored_resolution of this Asset.  # noqa: E501
        :type max_stored_resolution: str
        """
        allowed_values = ["Audio only", "SD", "HD", "FHD", "UHD"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and max_stored_resolution not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `max_stored_resolution` ({0}), must be one of {1}"  # noqa: E501
                .format(max_stored_resolution, allowed_values)
            )

        self._max_stored_resolution = max_stored_resolution

    @property
    def max_stored_frame_rate(self):
        """Gets the max_stored_frame_rate of this Asset.  # noqa: E501

        The maximum frame rate that has been stored for the asset. The asset may be delivered at lower frame rates depending on the device and bandwidth, however it cannot be delivered at a higher value than is stored. This field may return -1 if the frame rate of the input cannot be reliably determined.  # noqa: E501

        :return: The max_stored_frame_rate of this Asset.  # noqa: E501
        :rtype: float
        """
        return self._max_stored_frame_rate

    @max_stored_frame_rate.setter
    def max_stored_frame_rate(self, max_stored_frame_rate):
        """Sets the max_stored_frame_rate of this Asset.

        The maximum frame rate that has been stored for the asset. The asset may be delivered at lower frame rates depending on the device and bandwidth, however it cannot be delivered at a higher value than is stored. This field may return -1 if the frame rate of the input cannot be reliably determined.  # noqa: E501

        :param max_stored_frame_rate: The max_stored_frame_rate of this Asset.  # noqa: E501
        :type max_stored_frame_rate: float
        """

        self._max_stored_frame_rate = max_stored_frame_rate

    @property
    def aspect_ratio(self):
        """Gets the aspect_ratio of this Asset.  # noqa: E501

        The aspect ratio of the asset in the form of `width:height`, for example `16:9`.  # noqa: E501

        :return: The aspect_ratio of this Asset.  # noqa: E501
        :rtype: str
        """
        return self._aspect_ratio

    @aspect_ratio.setter
    def aspect_ratio(self, aspect_ratio):
        """Sets the aspect_ratio of this Asset.

        The aspect ratio of the asset in the form of `width:height`, for example `16:9`.  # noqa: E501

        :param aspect_ratio: The aspect_ratio of this Asset.  # noqa: E501
        :type aspect_ratio: str
        """

        self._aspect_ratio = aspect_ratio

    @property
    def playback_ids(self):
        """Gets the playback_ids of this Asset.  # noqa: E501

        An array of Playback ID objects. Use these to create HLS playback URLs. See [Play your videos](https://docs.mux.com/guides/video/play-your-videos) for more details.  # noqa: E501

        :return: The playback_ids of this Asset.  # noqa: E501
        :rtype: list[PlaybackID]
        """
        return self._playback_ids

    @playback_ids.setter
    def playback_ids(self, playback_ids):
        """Sets the playback_ids of this Asset.

        An array of Playback ID objects. Use these to create HLS playback URLs. See [Play your videos](https://docs.mux.com/guides/video/play-your-videos) for more details.  # noqa: E501

        :param playback_ids: The playback_ids of this Asset.  # noqa: E501
        :type playback_ids: list[PlaybackID]
        """

        self._playback_ids = playback_ids

    @property
    def tracks(self):
        """Gets the tracks of this Asset.  # noqa: E501

        The individual media tracks that make up an asset.  # noqa: E501

        :return: The tracks of this Asset.  # noqa: E501
        :rtype: list[Track]
        """
        return self._tracks

    @tracks.setter
    def tracks(self, tracks):
        """Sets the tracks of this Asset.

        The individual media tracks that make up an asset.  # noqa: E501

        :param tracks: The tracks of this Asset.  # noqa: E501
        :type tracks: list[Track]
        """

        self._tracks = tracks

    @property
    def errors(self):
        """Gets the errors of this Asset.  # noqa: E501


        :return: The errors of this Asset.  # noqa: E501
        :rtype: AssetErrors
        """
        return self._errors

    @errors.setter
    def errors(self, errors):
        """Sets the errors of this Asset.


        :param errors: The errors of this Asset.  # noqa: E501
        :type errors: AssetErrors
        """

        self._errors = errors

    @property
    def per_title_encode(self):
        """Gets the per_title_encode of this Asset.  # noqa: E501


        :return: The per_title_encode of this Asset.  # noqa: E501
        :rtype: bool
        """
        return self._per_title_encode

    @per_title_encode.setter
    def per_title_encode(self, per_title_encode):
        """Sets the per_title_encode of this Asset.


        :param per_title_encode: The per_title_encode of this Asset.  # noqa: E501
        :type per_title_encode: bool
        """

        self._per_title_encode = per_title_encode

    @property
    def upload_id(self):
        """Gets the upload_id of this Asset.  # noqa: E501

        Unique identifier for the Direct Upload. This is an optional parameter added when the asset is created from a direct upload.  # noqa: E501

        :return: The upload_id of this Asset.  # noqa: E501
        :rtype: str
        """
        return self._upload_id

    @upload_id.setter
    def upload_id(self, upload_id):
        """Sets the upload_id of this Asset.

        Unique identifier for the Direct Upload. This is an optional parameter added when the asset is created from a direct upload.  # noqa: E501

        :param upload_id: The upload_id of this Asset.  # noqa: E501
        :type upload_id: str
        """

        self._upload_id = upload_id

    @property
    def is_live(self):
        """Gets the is_live of this Asset.  # noqa: E501

        Whether the asset is created from a live stream and the live stream is currently `active` and not in `idle` state.  # noqa: E501

        :return: The is_live of this Asset.  # noqa: E501
        :rtype: bool
        """
        return self._is_live

    @is_live.setter
    def is_live(self, is_live):
        """Sets the is_live of this Asset.

        Whether the asset is created from a live stream and the live stream is currently `active` and not in `idle` state.  # noqa: E501

        :param is_live: The is_live of this Asset.  # noqa: E501
        :type is_live: bool
        """

        self._is_live = is_live

    @property
    def passthrough(self):
        """Gets the passthrough of this Asset.  # noqa: E501

        Arbitrary metadata set for the asset. Max 255 characters.  # noqa: E501

        :return: The passthrough of this Asset.  # noqa: E501
        :rtype: str
        """
        return self._passthrough

    @passthrough.setter
    def passthrough(self, passthrough):
        """Sets the passthrough of this Asset.

        Arbitrary metadata set for the asset. Max 255 characters.  # noqa: E501

        :param passthrough: The passthrough of this Asset.  # noqa: E501
        :type passthrough: str
        """

        self._passthrough = passthrough

    @property
    def live_stream_id(self):
        """Gets the live_stream_id of this Asset.  # noqa: E501

        Unique identifier for the live stream. This is an optional parameter added when the asset is created from a live stream.  # noqa: E501

        :return: The live_stream_id of this Asset.  # noqa: E501
        :rtype: str
        """
        return self._live_stream_id

    @live_stream_id.setter
    def live_stream_id(self, live_stream_id):
        """Sets the live_stream_id of this Asset.

        Unique identifier for the live stream. This is an optional parameter added when the asset is created from a live stream.  # noqa: E501

        :param live_stream_id: The live_stream_id of this Asset.  # noqa: E501
        :type live_stream_id: str
        """

        self._live_stream_id = live_stream_id

    @property
    def master(self):
        """Gets the master of this Asset.  # noqa: E501


        :return: The master of this Asset.  # noqa: E501
        :rtype: AssetMaster
        """
        return self._master

    @master.setter
    def master(self, master):
        """Sets the master of this Asset.


        :param master: The master of this Asset.  # noqa: E501
        :type master: AssetMaster
        """

        self._master = master

    @property
    def master_access(self):
        """Gets the master_access of this Asset.  # noqa: E501


        :return: The master_access of this Asset.  # noqa: E501
        :rtype: str
        """
        return self._master_access

    @master_access.setter
    def master_access(self, master_access):
        """Sets the master_access of this Asset.


        :param master_access: The master_access of this Asset.  # noqa: E501
        :type master_access: str
        """
        allowed_values = ["temporary", "none"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and master_access not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `master_access` ({0}), must be one of {1}"  # noqa: E501
                .format(master_access, allowed_values)
            )

        self._master_access = master_access

    @property
    def mp4_support(self):
        """Gets the mp4_support of this Asset.  # noqa: E501


        :return: The mp4_support of this Asset.  # noqa: E501
        :rtype: str
        """
        return self._mp4_support

    @mp4_support.setter
    def mp4_support(self, mp4_support):
        """Sets the mp4_support of this Asset.


        :param mp4_support: The mp4_support of this Asset.  # noqa: E501
        :type mp4_support: str
        """
        allowed_values = ["standard", "none"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and mp4_support not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `mp4_support` ({0}), must be one of {1}"  # noqa: E501
                .format(mp4_support, allowed_values)
            )

        self._mp4_support = mp4_support

    @property
    def source_asset_id(self):
        """Gets the source_asset_id of this Asset.  # noqa: E501

        Asset Identifier of the video used as the source for creating the clip.  # noqa: E501

        :return: The source_asset_id of this Asset.  # noqa: E501
        :rtype: str
        """
        return self._source_asset_id

    @source_asset_id.setter
    def source_asset_id(self, source_asset_id):
        """Sets the source_asset_id of this Asset.

        Asset Identifier of the video used as the source for creating the clip.  # noqa: E501

        :param source_asset_id: The source_asset_id of this Asset.  # noqa: E501
        :type source_asset_id: str
        """

        self._source_asset_id = source_asset_id

    @property
    def normalize_audio(self):
        """Gets the normalize_audio of this Asset.  # noqa: E501

        Normalize the audio track loudness level. This parameter is only applicable to on-demand (not live) assets.  # noqa: E501

        :return: The normalize_audio of this Asset.  # noqa: E501
        :rtype: bool
        """
        return self._normalize_audio

    @normalize_audio.setter
    def normalize_audio(self, normalize_audio):
        """Sets the normalize_audio of this Asset.

        Normalize the audio track loudness level. This parameter is only applicable to on-demand (not live) assets.  # noqa: E501

        :param normalize_audio: The normalize_audio of this Asset.  # noqa: E501
        :type normalize_audio: bool
        """

        self._normalize_audio = normalize_audio

    @property
    def static_renditions(self):
        """Gets the static_renditions of this Asset.  # noqa: E501


        :return: The static_renditions of this Asset.  # noqa: E501
        :rtype: AssetStaticRenditions
        """
        return self._static_renditions

    @static_renditions.setter
    def static_renditions(self, static_renditions):
        """Sets the static_renditions of this Asset.


        :param static_renditions: The static_renditions of this Asset.  # noqa: E501
        :type static_renditions: AssetStaticRenditions
        """

        self._static_renditions = static_renditions

    @property
    def recording_times(self):
        """Gets the recording_times of this Asset.  # noqa: E501

        An array of individual live stream recording sessions. A recording session is created on each encoder connection during the live stream  # noqa: E501

        :return: The recording_times of this Asset.  # noqa: E501
        :rtype: list[AssetRecordingTimes]
        """
        return self._recording_times

    @recording_times.setter
    def recording_times(self, recording_times):
        """Sets the recording_times of this Asset.

        An array of individual live stream recording sessions. A recording session is created on each encoder connection during the live stream  # noqa: E501

        :param recording_times: The recording_times of this Asset.  # noqa: E501
        :type recording_times: list[AssetRecordingTimes]
        """

        self._recording_times = recording_times

    @property
    def non_standard_input_reasons(self):
        """Gets the non_standard_input_reasons of this Asset.  # noqa: E501


        :return: The non_standard_input_reasons of this Asset.  # noqa: E501
        :rtype: AssetNonStandardInputReasons
        """
        return self._non_standard_input_reasons

    @non_standard_input_reasons.setter
    def non_standard_input_reasons(self, non_standard_input_reasons):
        """Sets the non_standard_input_reasons of this Asset.


        :param non_standard_input_reasons: The non_standard_input_reasons of this Asset.  # noqa: E501
        :type non_standard_input_reasons: AssetNonStandardInputReasons
        """

        self._non_standard_input_reasons = non_standard_input_reasons

    @property
    def test(self):
        """Gets the test of this Asset.  # noqa: E501

        True means this live stream is a test asset. A test asset can help evaluate the Mux Video APIs without incurring any cost. There is no limit on number of test assets created. Test assets are watermarked with the Mux logo, limited to 10 seconds, and deleted after 24 hrs.  # noqa: E501

        :return: The test of this Asset.  # noqa: E501
        :rtype: bool
        """
        return self._test

    @test.setter
    def test(self, test):
        """Sets the test of this Asset.

        True means this live stream is a test asset. A test asset can help evaluate the Mux Video APIs without incurring any cost. There is no limit on number of test assets created. Test assets are watermarked with the Mux logo, limited to 10 seconds, and deleted after 24 hrs.  # noqa: E501

        :param test: The test of this Asset.  # noqa: E501
        :type test: bool
        """

        self._test = test

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = inspect.getargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: convert(x),
                    value
                ))
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], convert(item[1])),
                    value.items()
                ))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Asset):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, Asset):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Mux API

    Mux is how developers build online video. This API encompasses both Mux Video and Mux Data functionality to help you build your video-related projects better and faster than ever before.  # noqa: E501

    The version of the OpenAPI document: v1
    Contact: devex@mux.com
    Generated by: https://openapi-generator.tech
"""


import inspect
import pprint
import re  # noqa: F401
import six

from mux_python.configuration import Configuration


class CreateAssetRequest(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'input': 'list[InputSettings]',
        'playback_policy': 'list[PlaybackPolicy]',
        'per_title_encode': 'bool',
        'passthrough': 'str',
        'mp4_support': 'str',
        'normalize_audio': 'bool',
        'master_access': 'str',
        'test': 'bool'
    }

    attribute_map = {
        'input': 'input',
        'playback_policy': 'playback_policy',
        'per_title_encode': 'per_title_encode',
        'passthrough': 'passthrough',
        'mp4_support': 'mp4_support',
        'normalize_audio': 'normalize_audio',
        'master_access': 'master_access',
        'test': 'test'
    }

    def __init__(self, input=None, playback_policy=None, per_title_encode=None, passthrough=None, mp4_support=None, normalize_audio=False, master_access=None, test=None, local_vars_configuration=None):  # noqa: E501
        """CreateAssetRequest - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default_copy()
        self.local_vars_configuration = local_vars_configuration

        self._input = None
        self._playback_policy = None
        self._per_title_encode = None
        self._passthrough = None
        self._mp4_support = None
        self._normalize_audio = None
        self._master_access = None
        self._test = None
        self.discriminator = None

        if input is not None:
            self.input = input
        if playback_policy is not None:
            self.playback_policy = playback_policy
        if per_title_encode is not None:
            self.per_title_encode = per_title_encode
        if passthrough is not None:
            self.passthrough = passthrough
        if mp4_support is not None:
            self.mp4_support = mp4_support
        if normalize_audio is not None:
            self.normalize_audio = normalize_audio
        if master_access is not None:
            self.master_access = master_access
        if test is not None:
            self.test = test

    @property
    def input(self):
        """Gets the input of this CreateAssetRequest.  # noqa: E501

        An array of objects that each describe an input file to be used to create the asset. As a shortcut, input can also be a string URL for a file when only one input file is used. See `input[].url` for requirements.  # noqa: E501

        :return: The input of this CreateAssetRequest.  # noqa: E501
        :rtype: list[InputSettings]
        """
        return self._input

    @input.setter
    def input(self, input):
        """Sets the input of this CreateAssetRequest.

        An array of objects that each describe an input file to be used to create the asset. As a shortcut, input can also be a string URL for a file when only one input file is used. See `input[].url` for requirements.  # noqa: E501

        :param input: The input of this CreateAssetRequest.  # noqa: E501
        :type input: list[InputSettings]
        """

        self._input = input

    @property
    def playback_policy(self):
        """Gets the playback_policy of this CreateAssetRequest.  # noqa: E501

        An array of playback policy names that you want applied to this asset and available through `playback_ids`. Options include: `\"public\"` (anyone with the playback URL can stream the asset). And `\"signed\"` (an additional access token is required to play the asset). If no playback_policy is set, the asset will have no playback IDs and will therefore not be playable. For simplicity, a single string name can be used in place of the array in the case of only one playback policy.  # noqa: E501

        :return: The playback_policy of this CreateAssetRequest.  # noqa: E501
        :rtype: list[PlaybackPolicy]
        """
        return self._playback_policy

    @playback_policy.setter
    def playback_policy(self, playback_policy):
        """Sets the playback_policy of this CreateAssetRequest.

        An array of playback policy names that you want applied to this asset and available through `playback_ids`. Options include: `\"public\"` (anyone with the playback URL can stream the asset). And `\"signed\"` (an additional access token is required to play the asset). If no playback_policy is set, the asset will have no playback IDs and will therefore not be playable. For simplicity, a single string name can be used in place of the array in the case of only one playback policy.  # noqa: E501

        :param playback_policy: The playback_policy of this CreateAssetRequest.  # noqa: E501
        :type playback_policy: list[PlaybackPolicy]
        """

        self._playback_policy = playback_policy

    @property
    def per_title_encode(self):
        """Gets the per_title_encode of this CreateAssetRequest.  # noqa: E501


        :return: The per_title_encode of this CreateAssetRequest.  # noqa: E501
        :rtype: bool
        """
        return self._per_title_encode

    @per_title_encode.setter
    def per_title_encode(self, per_title_encode):
        """Sets the per_title_encode of this CreateAssetRequest.


        :param per_title_encode: The per_title_encode of this CreateAssetRequest.  # noqa: E501
        :type per_title_encode: bool
        """

        self._per_title_encode = per_title_encode

    @property
    def passthrough(self):
        """Gets the passthrough of this CreateAssetRequest.  # noqa: E501

        Arbitrary metadata that will be included in the asset details and related webhooks. Can be used to store your own ID for a video along with the asset. **Max: 255 characters**.  # noqa: E501

        :return: The passthrough of this CreateAssetRequest.  # noqa: E501
        :rtype: str
        """
        return self._passthrough

    @passthrough.setter
    def passthrough(self, passthrough):
        """Sets the passthrough of this CreateAssetRequest.

        Arbitrary metadata that will be included in the asset details and related webhooks. Can be used to store your own ID for a video along with the asset. **Max: 255 characters**.  # noqa: E501

        :param passthrough: The passthrough of this CreateAssetRequest.  # noqa: E501
        :type passthrough: str
        """

        self._passthrough = passthrough

    @property
    def mp4_support(self):
        """Gets the mp4_support of this CreateAssetRequest.  # noqa: E501

        Specify what level (if any) of support for mp4 playback. In most cases you should use our default HLS-based streaming playback ({playback_id}.m3u8) which can automatically adjust to viewers' connection speeds, but an mp4 can be useful for some legacy devices or downloading for offline playback. See the [Download your videos guide](/guides/video/download-your-videos) for more information.  # noqa: E501

        :return: The mp4_support of this CreateAssetRequest.  # noqa: E501
        :rtype: str
        """
        return self._mp4_support

    @mp4_support.setter
    def mp4_support(self, mp4_support):
        """Sets the mp4_support of this CreateAssetRequest.

        Specify what level (if any) of support for mp4 playback. In most cases you should use our default HLS-based streaming playback ({playback_id}.m3u8) which can automatically adjust to viewers' connection speeds, but an mp4 can be useful for some legacy devices or downloading for offline playback. See the [Download your videos guide](/guides/video/download-your-videos) for more information.  # noqa: E501

        :param mp4_support: The mp4_support of this CreateAssetRequest.  # noqa: E501
        :type mp4_support: str
        """
        allowed_values = ["none", "standard"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and mp4_support not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `mp4_support` ({0}), must be one of {1}"  # noqa: E501
                .format(mp4_support, allowed_values)
            )

        self._mp4_support = mp4_support

    @property
    def normalize_audio(self):
        """Gets the normalize_audio of this CreateAssetRequest.  # noqa: E501

        Normalize the audio track loudness level. This parameter is only applicable to on-demand (not live) assets.  # noqa: E501

        :return: The normalize_audio of this CreateAssetRequest.  # noqa: E501
        :rtype: bool
        """
        return self._normalize_audio

    @normalize_audio.setter
    def normalize_audio(self, normalize_audio):
        """Sets the normalize_audio of this CreateAssetRequest.

        Normalize the audio track loudness level. This parameter is only applicable to on-demand (not live) assets.  # noqa: E501

        :param normalize_audio: The normalize_audio of this CreateAssetRequest.  # noqa: E501
        :type normalize_audio: bool
        """

        self._normalize_audio = normalize_audio

    @property
    def master_access(self):
        """Gets the master_access of this CreateAssetRequest.  # noqa: E501

        Specify what level (if any) of support for master access. Master access can be enabled temporarily for your asset to be downloaded. See the [Download your videos guide](/guides/video/download-your-videos) for more information.  # noqa: E501

        :return: The master_access of this CreateAssetRequest.  # noqa: E501
        :rtype: str
        """
        return self._master_access

    @master_access.setter
    def master_access(self, master_access):
        """Sets the master_access of this CreateAssetRequest.

        Specify what level (if any) of support for master access. Master access can be enabled temporarily for your asset to be downloaded. See the [Download your videos guide](/guides/video/download-your-videos) for more information.  # noqa: E501

        :param master_access: The master_access of this CreateAssetRequest.  # noqa: E501
        :type master_access: str
        """
        allowed_values = ["none", "temporary"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and master_access not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `master_access` ({0}), must be one of {1}"  # noqa: E501
                .format(master_access, allowed_values)
            )

        self._master_access = master_access

    @property
    def test(self):
        """Gets the test of this CreateAssetRequest.  # noqa: E501

        Marks the asset as a test asset when the value is set to true. A Test asset can help evaluate the Mux Video APIs without incurring any cost. There is no limit on number of test assets created. Test asset are watermarked with the Mux logo, limited to 10 seconds, deleted after 24 hrs.  # noqa: E501

        :return: The test of this CreateAssetRequest.  # noqa: E501
        :rtype: bool
        """
        return self._test

    @test.setter
    def test(self, test):
        """Sets the test of this CreateAssetRequest.

        Marks the asset as a test asset when the value is set to true. A Test asset can help evaluate the Mux Video APIs without incurring any cost. There is no limit on number of test assets created. Test asset are watermarked with the Mux logo, limited to 10 seconds, deleted after 24 hrs.  # noqa: E501

        :param test: The test of this CreateAssetRequest.  # noqa: E501
        :type test: bool
        """

        self._test = test

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = inspect.getargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: convert(x),
                    value
                ))
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], convert(item[1])),
                    value.items()
                ))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CreateAssetRequest):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, CreateAssetRequest):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
Mux Python - Copyright 2019 Mux Inc.

NOTE: This class is auto generated. Do not edit the class manually.
"""


from __future__ import absolute_import

import unittest

import mux_python
from mux_python.api.playback_id_api import PlaybackIDApi  # noqa: E501
from mux_python.rest import ApiException


class TestPlaybackIDApi(unittest.TestCase):
    """PlaybackIDApi unit test stubs"""

    def setUp(self):
        self.api = mux_python.api.playback_id_api.PlaybackIDApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_get_asset_or_livestream_id(self):
        """Test case for get_asset_or_livestream_id

        Retrieve an Asset or Live Stream ID  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Mux API

    Mux is how developers build online video. This API encompasses both Mux Video and Mux Data functionality to help you build your video-related projects better and faster than ever before.  # noqa: E501

    The version of the OpenAPI document: v1
    Contact: devex@mux.com
    Generated by: https://openapi-generator.tech
"""


import inspect
import pprint
import re  # noqa: F401
import six

from mux_python.configuration import Configuration


class RealTimeHistogramTimeseriesDatapoint(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'timestamp': 'str',
        'sum': 'int',
        'p95': 'float',
        'median': 'float',
        'max_percentage': 'float',
        'bucket_values': 'list[RealTimeHistogramTimeseriesBucketValues]',
        'average': 'float'
    }

    attribute_map = {
        'timestamp': 'timestamp',
        'sum': 'sum',
        'p95': 'p95',
        'median': 'median',
        'max_percentage': 'max_percentage',
        'bucket_values': 'bucket_values',
        'average': 'average'
    }

    def __init__(self, timestamp=None, sum=None, p95=None, median=None, max_percentage=None, bucket_values=None, average=None, local_vars_configuration=None):  # noqa: E501
        """RealTimeHistogramTimeseriesDatapoint - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default_copy()
        self.local_vars_configuration = local_vars_configuration

        self._timestamp = None
        self._sum = None
        self._p95 = None
        self._median = None
        self._max_percentage = None
        self._bucket_values = None
        self._average = None
        self.discriminator = None

        if timestamp is not None:
            self.timestamp = timestamp
        if sum is not None:
            self.sum = sum
        if p95 is not None:
            self.p95 = p95
        if median is not None:
            self.median = median
        if max_percentage is not None:
            self.max_percentage = max_percentage
        if bucket_values is not None:
            self.bucket_values = bucket_values
        if average is not None:
            self.average = average

    @property
    def timestamp(self):
        """Gets the timestamp of this RealTimeHistogramTimeseriesDatapoint.  # noqa: E501


        :return: The timestamp of this RealTimeHistogramTimeseriesDatapoint.  # noqa: E501
        :rtype: str
        """
        return self._timestamp

    @timestamp.setter
    def timestamp(self, timestamp):
        """Sets the timestamp of this RealTimeHistogramTimeseriesDatapoint.


        :param timestamp: The timestamp of this RealTimeHistogramTimeseriesDatapoint.  # noqa: E501
        :type timestamp: str
        """

        self._timestamp = timestamp

    @property
    def sum(self):
        """Gets the sum of this RealTimeHistogramTimeseriesDatapoint.  # noqa: E501


        :return: The sum of this RealTimeHistogramTimeseriesDatapoint.  # noqa: E501
        :rtype: int
        """
        return self._sum

    @sum.setter
    def sum(self, sum):
        """Sets the sum of this RealTimeHistogramTimeseriesDatapoint.


        :param sum: The sum of this RealTimeHistogramTimeseriesDatapoint.  # noqa: E501
        :type sum: int
        """

        self._sum = sum

    @property
    def p95(self):
        """Gets the p95 of this RealTimeHistogramTimeseriesDatapoint.  # noqa: E501


        :return: The p95 of this RealTimeHistogramTimeseriesDatapoint.  # noqa: E501
        :rtype: float
        """
        return self._p95

    @p95.setter
    def p95(self, p95):
        """Sets the p95 of this RealTimeHistogramTimeseriesDatapoint.


        :param p95: The p95 of this RealTimeHistogramTimeseriesDatapoint.  # noqa: E501
        :type p95: float
        """

        self._p95 = p95

    @property
    def median(self):
        """Gets the median of this RealTimeHistogramTimeseriesDatapoint.  # noqa: E501


        :return: The median of this RealTimeHistogramTimeseriesDatapoint.  # noqa: E501
        :rtype: float
        """
        return self._median

    @median.setter
    def median(self, median):
        """Sets the median of this RealTimeHistogramTimeseriesDatapoint.


        :param median: The median of this RealTimeHistogramTimeseriesDatapoint.  # noqa: E501
        :type median: float
        """

        self._median = median

    @property
    def max_percentage(self):
        """Gets the max_percentage of this RealTimeHistogramTimeseriesDatapoint.  # noqa: E501


        :return: The max_percentage of this RealTimeHistogramTimeseriesDatapoint.  # noqa: E501
        :rtype: float
        """
        return self._max_percentage

    @max_percentage.setter
    def max_percentage(self, max_percentage):
        """Sets the max_percentage of this RealTimeHistogramTimeseriesDatapoint.


        :param max_percentage: The max_percentage of this RealTimeHistogramTimeseriesDatapoint.  # noqa: E501
        :type max_percentage: float
        """

        self._max_percentage = max_percentage

    @property
    def bucket_values(self):
        """Gets the bucket_values of this RealTimeHistogramTimeseriesDatapoint.  # noqa: E501


        :return: The bucket_values of this RealTimeHistogramTimeseriesDatapoint.  # noqa: E501
        :rtype: list[RealTimeHistogramTimeseriesBucketValues]
        """
        return self._bucket_values

    @bucket_values.setter
    def bucket_values(self, bucket_values):
        """Sets the bucket_values of this RealTimeHistogramTimeseriesDatapoint.


        :param bucket_values: The bucket_values of this RealTimeHistogramTimeseriesDatapoint.  # noqa: E501
        :type bucket_values: list[RealTimeHistogramTimeseriesBucketValues]
        """

        self._bucket_values = bucket_values

    @property
    def average(self):
        """Gets the average of this RealTimeHistogramTimeseriesDatapoint.  # noqa: E501


        :return: The average of this RealTimeHistogramTimeseriesDatapoint.  # noqa: E501
        :rtype: float
        """
        return self._average

    @average.setter
    def average(self, average):
        """Sets the average of this RealTimeHistogramTimeseriesDatapoint.


        :param average: The average of this RealTimeHistogramTimeseriesDatapoint.  # noqa: E501
        :type average: float
        """

        self._average = average

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = inspect.getargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: convert(x),
                    value
                ))
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], convert(item[1])),
                    value.items()
                ))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, RealTimeHistogramTimeseriesDatapoint):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, RealTimeHistogramTimeseriesDatapoint):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Mux API

    Mux is how developers build online video. This API encompasses both Mux Video and Mux Data functionality to help you build your video-related projects better and faster than ever before.  # noqa: E501

    The version of the OpenAPI document: v1
    Contact: devex@mux.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from mux_python.api_client import ApiClient
from mux_python.exceptions import (  # noqa: F401
    ApiTypeError,
    ApiValueError
)


class MetricsApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def get_metric_timeseries_data(self, metric_id, **kwargs):  # noqa: E501
        """Get metric timeseries data  # noqa: E501

        Returns timeseries data for a specific metric.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_metric_timeseries_data(metric_id, async_req=True)
        >>> result = thread.get()

        :param metric_id: ID of the Metric (required)
        :type metric_id: str
        :param timeframe: Timeframe window to limit results by. Must be provided as an array query string parameter (e.g. timeframe[]=). Accepted formats are...   * array of epoch timestamps e.g. timeframe[]=1498867200&timeframe[]=1498953600   * duration string e.g. timeframe[]=24:hours or timeframe[]=7:days. 
        :type timeframe: list[str]
        :param filters: Filter key:value pairs. Must be provided as an array query string parameter (e.g. filters[]=operating_system:windows&filters[]=country:US). Possible filter names are the same as returned by the List Filters endpoint. 
        :type filters: list[str]
        :param measurement: Measurement for the provided metric. If omitted, the default for the metric will be used.
        :type measurement: str
        :param order_direction: Sort order.
        :type order_direction: str
        :param group_by: Time granularity to group results by. If this value is omitted, a default granularity is chosen based on the supplied timeframe.
        :type group_by: str
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: GetMetricTimeseriesDataResponse
        """
        kwargs['_return_http_data_only'] = True
        return self.get_metric_timeseries_data_with_http_info(metric_id, **kwargs)  # noqa: E501

    def get_metric_timeseries_data_with_http_info(self, metric_id, **kwargs):  # noqa: E501
        """Get metric timeseries data  # noqa: E501

        Returns timeseries data for a specific metric.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_metric_timeseries_data_with_http_info(metric_id, async_req=True)
        >>> result = thread.get()

        :param metric_id: ID of the Metric (required)
        :type metric_id: str
        :param timeframe: Timeframe window to limit results by. Must be provided as an array query string parameter (e.g. timeframe[]=). Accepted formats are...   * array of epoch timestamps e.g. timeframe[]=1498867200&timeframe[]=1498953600   * duration string e.g. timeframe[]=24:hours or timeframe[]=7:days. 
        :type timeframe: list[str]
        :param filters: Filter key:value pairs. Must be provided as an array query string parameter (e.g. filters[]=operating_system:windows&filters[]=country:US). Possible filter names are the same as returned by the List Filters endpoint. 
        :type filters: list[str]
        :param measurement: Measurement for the provided metric. If omitted, the default for the metric will be used.
        :type measurement: str
        :param order_direction: Sort order.
        :type order_direction: str
        :param group_by: Time granularity to group results by. If this value is omitted, a default granularity is chosen based on the supplied timeframe.
        :type group_by: str
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _return_http_data_only: response data without head status code
                                       and headers
        :type _return_http_data_only: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(GetMetricTimeseriesDataResponse, status_code(int), headers(HTTPHeaderDict))
        """

        local_var_params = locals()

        all_params = [
            'metric_id',
            'timeframe',
            'filters',
            'measurement',
            'order_direction',
            'group_by'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_metric_timeseries_data" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'metric_id' is set
        if self.api_client.client_side_validation and ('metric_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['metric_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `metric_id` when calling `get_metric_timeseries_data`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'metric_id' in local_var_params:
            path_params['METRIC_ID'] = local_var_params['metric_id']  # noqa: E501

        query_params = []
        if 'timeframe' in local_var_params and local_var_params['timeframe'] is not None:  # noqa: E501
            query_params.append(('timeframe[]', local_var_params['timeframe']))  # noqa: E501
            collection_formats['timeframe[]'] = 'multi'  # noqa: E501
        if 'filters' in local_var_params and local_var_params['filters'] is not None:  # noqa: E501
            query_params.append(('filters[]', local_var_params['filters']))  # noqa: E501
            collection_formats['filters[]'] = 'multi'  # noqa: E501
        if 'measurement' in local_var_params and local_var_params['measurement'] is not None:  # noqa: E501
            query_params.append(('measurement', local_var_params['measurement']))  # noqa: E501
        if 'order_direction' in local_var_params and local_var_params['order_direction'] is not None:  # noqa: E501
            query_params.append(('order_direction', local_var_params['order_direction']))  # noqa: E501
        if 'group_by' in local_var_params and local_var_params['group_by'] is not None:  # noqa: E501
            query_params.append(('group_by', local_var_params['group_by']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['accessToken']  # noqa: E501
        
        response_types_map = {
            200: "GetMetricTimeseriesDataResponse",
        }

        return self.api_client.call_api(
            '/data/v1/metrics/{METRIC_ID}/timeseries', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_types_map=response_types_map,
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats,
            _request_auth=local_var_params.get('_request_auth'))

    def get_overall_values(self, metric_id, **kwargs):  # noqa: E501
        """Get Overall values  # noqa: E501

        Returns the overall value for a specific metric, as well as the total view count, watch time, and the Mux Global metric value for the metric.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_overall_values(metric_id, async_req=True)
        >>> result = thread.get()

        :param metric_id: ID of the Metric (required)
        :type metric_id: str
        :param timeframe: Timeframe window to limit results by. Must be provided as an array query string parameter (e.g. timeframe[]=). Accepted formats are...   * array of epoch timestamps e.g. timeframe[]=1498867200&timeframe[]=1498953600   * duration string e.g. timeframe[]=24:hours or timeframe[]=7:days. 
        :type timeframe: list[str]
        :param filters: Filter key:value pairs. Must be provided as an array query string parameter (e.g. filters[]=operating_system:windows&filters[]=country:US). Possible filter names are the same as returned by the List Filters endpoint. 
        :type filters: list[str]
        :param measurement: Measurement for the provided metric. If omitted, the default for the metric will be used.
        :type measurement: str
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: GetOverallValuesResponse
        """
        kwargs['_return_http_data_only'] = True
        return self.get_overall_values_with_http_info(metric_id, **kwargs)  # noqa: E501

    def get_overall_values_with_http_info(self, metric_id, **kwargs):  # noqa: E501
        """Get Overall values  # noqa: E501

        Returns the overall value for a specific metric, as well as the total view count, watch time, and the Mux Global metric value for the metric.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_overall_values_with_http_info(metric_id, async_req=True)
        >>> result = thread.get()

        :param metric_id: ID of the Metric (required)
        :type metric_id: str
        :param timeframe: Timeframe window to limit results by. Must be provided as an array query string parameter (e.g. timeframe[]=). Accepted formats are...   * array of epoch timestamps e.g. timeframe[]=1498867200&timeframe[]=1498953600   * duration string e.g. timeframe[]=24:hours or timeframe[]=7:days. 
        :type timeframe: list[str]
        :param filters: Filter key:value pairs. Must be provided as an array query string parameter (e.g. filters[]=operating_system:windows&filters[]=country:US). Possible filter names are the same as returned by the List Filters endpoint. 
        :type filters: list[str]
        :param measurement: Measurement for the provided metric. If omitted, the default for the metric will be used.
        :type measurement: str
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _return_http_data_only: response data without head status code
                                       and headers
        :type _return_http_data_only: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(GetOverallValuesResponse, status_code(int), headers(HTTPHeaderDict))
        """

        local_var_params = locals()

        all_params = [
            'metric_id',
            'timeframe',
            'filters',
            'measurement'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_overall_values" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'metric_id' is set
        if self.api_client.client_side_validation and ('metric_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['metric_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `metric_id` when calling `get_overall_values`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'metric_id' in local_var_params:
            path_params['METRIC_ID'] = local_var_params['metric_id']  # noqa: E501

        query_params = []
        if 'timeframe' in local_var_params and local_var_params['timeframe'] is not None:  # noqa: E501
            query_params.append(('timeframe[]', local_var_params['timeframe']))  # noqa: E501
            collection_formats['timeframe[]'] = 'multi'  # noqa: E501
        if 'filters' in local_var_params and local_var_params['filters'] is not None:  # noqa: E501
            query_params.append(('filters[]', local_var_params['filters']))  # noqa: E501
            collection_formats['filters[]'] = 'multi'  # noqa: E501
        if 'measurement' in local_var_params and local_var_params['measurement'] is not None:  # noqa: E501
            query_params.append(('measurement', local_var_params['measurement']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['accessToken']  # noqa: E501
        
        response_types_map = {
            200: "GetOverallValuesResponse",
        }

        return self.api_client.call_api(
            '/data/v1/metrics/{METRIC_ID}/overall', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_types_map=response_types_map,
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats,
            _request_auth=local_var_params.get('_request_auth'))

    def list_all_metric_values(self, **kwargs):  # noqa: E501
        """List all metric values  # noqa: E501

        List all of the values across every breakdown for a specific metric.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.list_all_metric_values(async_req=True)
        >>> result = thread.get()

        :param timeframe: Timeframe window to limit results by. Must be provided as an array query string parameter (e.g. timeframe[]=). Accepted formats are...   * array of epoch timestamps e.g. timeframe[]=1498867200&timeframe[]=1498953600   * duration string e.g. timeframe[]=24:hours or timeframe[]=7:days. 
        :type timeframe: list[str]
        :param filters: Filter key:value pairs. Must be provided as an array query string parameter (e.g. filters[]=operating_system:windows&filters[]=country:US). Possible filter names are the same as returned by the List Filters endpoint. 
        :type filters: list[str]
        :param dimension: Dimension the specified value belongs to
        :type dimension: str
        :param value: Value to show all available metrics for
        :type value: str
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: ListAllMetricValuesResponse
        """
        kwargs['_return_http_data_only'] = True
        return self.list_all_metric_values_with_http_info(**kwargs)  # noqa: E501

    def list_all_metric_values_with_http_info(self, **kwargs):  # noqa: E501
        """List all metric values  # noqa: E501

        List all of the values across every breakdown for a specific metric.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.list_all_metric_values_with_http_info(async_req=True)
        >>> result = thread.get()

        :param timeframe: Timeframe window to limit results by. Must be provided as an array query string parameter (e.g. timeframe[]=). Accepted formats are...   * array of epoch timestamps e.g. timeframe[]=1498867200&timeframe[]=1498953600   * duration string e.g. timeframe[]=24:hours or timeframe[]=7:days. 
        :type timeframe: list[str]
        :param filters: Filter key:value pairs. Must be provided as an array query string parameter (e.g. filters[]=operating_system:windows&filters[]=country:US). Possible filter names are the same as returned by the List Filters endpoint. 
        :type filters: list[str]
        :param dimension: Dimension the specified value belongs to
        :type dimension: str
        :param value: Value to show all available metrics for
        :type value: str
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _return_http_data_only: response data without head status code
                                       and headers
        :type _return_http_data_only: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(ListAllMetricValuesResponse, status_code(int), headers(HTTPHeaderDict))
        """

        local_var_params = locals()

        all_params = [
            'timeframe',
            'filters',
            'dimension',
            'value'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method list_all_metric_values" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'timeframe' in local_var_params and local_var_params['timeframe'] is not None:  # noqa: E501
            query_params.append(('timeframe[]', local_var_params['timeframe']))  # noqa: E501
            collection_formats['timeframe[]'] = 'multi'  # noqa: E501
        if 'filters' in local_var_params and local_var_params['filters'] is not None:  # noqa: E501
            query_params.append(('filters[]', local_var_params['filters']))  # noqa: E501
            collection_formats['filters[]'] = 'multi'  # noqa: E501
        if 'dimension' in local_var_params and local_var_params['dimension'] is not None:  # noqa: E501
            query_params.append(('dimension', local_var_params['dimension']))  # noqa: E501
        if 'value' in local_var_params and local_var_params['value'] is not None:  # noqa: E501
            query_params.append(('value', local_var_params['value']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['accessToken']  # noqa: E501
        
        response_types_map = {
            200: "ListAllMetricValuesResponse",
        }

        return self.api_client.call_api(
            '/data/v1/metrics/comparison', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_types_map=response_types_map,
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats,
            _request_auth=local_var_params.get('_request_auth'))

    def list_breakdown_values(self, metric_id, **kwargs):  # noqa: E501
        """List breakdown values  # noqa: E501

        List the breakdown values for a specific metric.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.list_breakdown_values(metric_id, async_req=True)
        >>> result = thread.get()

        :param metric_id: ID of the Metric (required)
        :type metric_id: str
        :param group_by: Breakdown value to group the results by
        :type group_by: str
        :param measurement: Measurement for the provided metric. If omitted, the default for the metric will be used.
        :type measurement: str
        :param filters: Filter key:value pairs. Must be provided as an array query string parameter (e.g. filters[]=operating_system:windows&filters[]=country:US). Possible filter names are the same as returned by the List Filters endpoint. 
        :type filters: list[str]
        :param limit: Number of items to include in the response
        :type limit: int
        :param page: Offset by this many pages, of the size of `limit`
        :type page: int
        :param order_by: Value to order the results by
        :type order_by: str
        :param order_direction: Sort order.
        :type order_direction: str
        :param timeframe: Timeframe window to limit results by. Must be provided as an array query string parameter (e.g. timeframe[]=). Accepted formats are...   * array of epoch timestamps e.g. timeframe[]=1498867200&timeframe[]=1498953600   * duration string e.g. timeframe[]=24:hours or timeframe[]=7:days. 
        :type timeframe: list[str]
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: ListBreakdownValuesResponse
        """
        kwargs['_return_http_data_only'] = True
        return self.list_breakdown_values_with_http_info(metric_id, **kwargs)  # noqa: E501

    def list_breakdown_values_with_http_info(self, metric_id, **kwargs):  # noqa: E501
        """List breakdown values  # noqa: E501

        List the breakdown values for a specific metric.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.list_breakdown_values_with_http_info(metric_id, async_req=True)
        >>> result = thread.get()

        :param metric_id: ID of the Metric (required)
        :type metric_id: str
        :param group_by: Breakdown value to group the results by
        :type group_by: str
        :param measurement: Measurement for the provided metric. If omitted, the default for the metric will be used.
        :type measurement: str
        :param filters: Filter key:value pairs. Must be provided as an array query string parameter (e.g. filters[]=operating_system:windows&filters[]=country:US). Possible filter names are the same as returned by the List Filters endpoint. 
        :type filters: list[str]
        :param limit: Number of items to include in the response
        :type limit: int
        :param page: Offset by this many pages, of the size of `limit`
        :type page: int
        :param order_by: Value to order the results by
        :type order_by: str
        :param order_direction: Sort order.
        :type order_direction: str
        :param timeframe: Timeframe window to limit results by. Must be provided as an array query string parameter (e.g. timeframe[]=). Accepted formats are...   * array of epoch timestamps e.g. timeframe[]=1498867200&timeframe[]=1498953600   * duration string e.g. timeframe[]=24:hours or timeframe[]=7:days. 
        :type timeframe: list[str]
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _return_http_data_only: response data without head status code
                                       and headers
        :type _return_http_data_only: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(ListBreakdownValuesResponse, status_code(int), headers(HTTPHeaderDict))
        """

        local_var_params = locals()

        all_params = [
            'metric_id',
            'group_by',
            'measurement',
            'filters',
            'limit',
            'page',
            'order_by',
            'order_direction',
            'timeframe'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method list_breakdown_values" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'metric_id' is set
        if self.api_client.client_side_validation and ('metric_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['metric_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `metric_id` when calling `list_breakdown_values`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'metric_id' in local_var_params:
            path_params['METRIC_ID'] = local_var_params['metric_id']  # noqa: E501

        query_params = []
        if 'group_by' in local_var_params and local_var_params['group_by'] is not None:  # noqa: E501
            query_params.append(('group_by', local_var_params['group_by']))  # noqa: E501
        if 'measurement' in local_var_params and local_var_params['measurement'] is not None:  # noqa: E501
            query_params.append(('measurement', local_var_params['measurement']))  # noqa: E501
        if 'filters' in local_var_params and local_var_params['filters'] is not None:  # noqa: E501
            query_params.append(('filters[]', local_var_params['filters']))  # noqa: E501
            collection_formats['filters[]'] = 'multi'  # noqa: E501
        if 'limit' in local_var_params and local_var_params['limit'] is not None:  # noqa: E501
            query_params.append(('limit', local_var_params['limit']))  # noqa: E501
        if 'page' in local_var_params and local_var_params['page'] is not None:  # noqa: E501
            query_params.append(('page', local_var_params['page']))  # noqa: E501
        if 'order_by' in local_var_params and local_var_params['order_by'] is not None:  # noqa: E501
            query_params.append(('order_by', local_var_params['order_by']))  # noqa: E501
        if 'order_direction' in local_var_params and local_var_params['order_direction'] is not None:  # noqa: E501
            query_params.append(('order_direction', local_var_params['order_direction']))  # noqa: E501
        if 'timeframe' in local_var_params and local_var_params['timeframe'] is not None:  # noqa: E501
            query_params.append(('timeframe[]', local_var_params['timeframe']))  # noqa: E501
            collection_formats['timeframe[]'] = 'multi'  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['accessToken']  # noqa: E501
        
        response_types_map = {
            200: "ListBreakdownValuesResponse",
        }

        return self.api_client.call_api(
            '/data/v1/metrics/{METRIC_ID}/breakdown', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_types_map=response_types_map,
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats,
            _request_auth=local_var_params.get('_request_auth'))

    def list_insights(self, metric_id, **kwargs):  # noqa: E501
        """List Insights  # noqa: E501

        Returns a list of insights for a metric. These are the worst performing values across all breakdowns sorted by how much they negatively impact a specific metric.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.list_insights(metric_id, async_req=True)
        >>> result = thread.get()

        :param metric_id: ID of the Metric (required)
        :type metric_id: str
        :param measurement: Measurement for the provided metric. If omitted, the default for the metric will be used.
        :type measurement: str
        :param order_direction: Sort order.
        :type order_direction: str
        :param timeframe: Timeframe window to limit results by. Must be provided as an array query string parameter (e.g. timeframe[]=). Accepted formats are...   * array of epoch timestamps e.g. timeframe[]=1498867200&timeframe[]=1498953600   * duration string e.g. timeframe[]=24:hours or timeframe[]=7:days. 
        :type timeframe: list[str]
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: ListInsightsResponse
        """
        kwargs['_return_http_data_only'] = True
        return self.list_insights_with_http_info(metric_id, **kwargs)  # noqa: E501

    def list_insights_with_http_info(self, metric_id, **kwargs):  # noqa: E501
        """List Insights  # noqa: E501

        Returns a list of insights for a metric. These are the worst performing values across all breakdowns sorted by how much they negatively impact a specific metric.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.list_insights_with_http_info(metric_id, async_req=True)
        >>> result = thread.get()

        :param metric_id: ID of the Metric (required)
        :type metric_id: str
        :param measurement: Measurement for the provided metric. If omitted, the default for the metric will be used.
        :type measurement: str
        :param order_direction: Sort order.
        :type order_direction: str
        :param timeframe: Timeframe window to limit results by. Must be provided as an array query string parameter (e.g. timeframe[]=). Accepted formats are...   * array of epoch timestamps e.g. timeframe[]=1498867200&timeframe[]=1498953600   * duration string e.g. timeframe[]=24:hours or timeframe[]=7:days. 
        :type timeframe: list[str]
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _return_http_data_only: response data without head status code
                                       and headers
        :type _return_http_data_only: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(ListInsightsResponse, status_code(int), headers(HTTPHeaderDict))
        """

        local_var_params = locals()

        all_params = [
            'metric_id',
            'measurement',
            'order_direction',
            'timeframe'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method list_insights" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'metric_id' is set
        if self.api_client.client_side_validation and ('metric_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['metric_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `metric_id` when calling `list_insights`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'metric_id' in local_var_params:
            path_params['METRIC_ID'] = local_var_params['metric_id']  # noqa: E501

        query_params = []
        if 'measurement' in local_var_params and local_var_params['measurement'] is not None:  # noqa: E501
            query_params.append(('measurement', local_var_params['measurement']))  # noqa: E501
        if 'order_direction' in local_var_params and local_var_params['order_direction'] is not None:  # noqa: E501
            query_params.append(('order_direction', local_var_params['order_direction']))  # noqa: E501
        if 'timeframe' in local_var_params and local_var_params['timeframe'] is not None:  # noqa: E501
            query_params.append(('timeframe[]', local_var_params['timeframe']))  # noqa: E501
            collection_formats['timeframe[]'] = 'multi'  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['accessToken']  # noqa: E501
        
        response_types_map = {
            200: "ListInsightsResponse",
        }

        return self.api_client.call_api(
            '/data/v1/metrics/{METRIC_ID}/insights', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_types_map=response_types_map,
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats,
            _request_auth=local_var_params.get('_request_auth'))



# coding: utf-8

"""
    Mux API

    Mux is how developers build online video. This API encompasses both Mux Video and Mux Data functionality to help you build your video-related projects better and faster than ever before.  # noqa: E501

    The version of the OpenAPI document: v1
    Contact: devex@mux.com
    Generated by: https://openapi-generator.tech
"""


import inspect
import pprint
import re  # noqa: F401
import six

from mux_python.configuration import Configuration


class Incident(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'threshold': 'float',
        'status': 'str',
        'started_at': 'str',
        'severity': 'str',
        'sample_size_unit': 'str',
        'sample_size': 'int',
        'resolved_at': 'str',
        'notifications': 'list[IncidentNotification]',
        'notification_rules': 'list[IncidentNotificationRule]',
        'measurement': 'str',
        'measured_value_on_close': 'float',
        'measured_value': 'float',
        'incident_key': 'str',
        'impact': 'str',
        'id': 'str',
        'error_description': 'str',
        'description': 'str',
        'breakdowns': 'list[IncidentBreakdown]',
        'affected_views_per_hour_on_open': 'int',
        'affected_views_per_hour': 'int',
        'affected_views': 'int'
    }

    attribute_map = {
        'threshold': 'threshold',
        'status': 'status',
        'started_at': 'started_at',
        'severity': 'severity',
        'sample_size_unit': 'sample_size_unit',
        'sample_size': 'sample_size',
        'resolved_at': 'resolved_at',
        'notifications': 'notifications',
        'notification_rules': 'notification_rules',
        'measurement': 'measurement',
        'measured_value_on_close': 'measured_value_on_close',
        'measured_value': 'measured_value',
        'incident_key': 'incident_key',
        'impact': 'impact',
        'id': 'id',
        'error_description': 'error_description',
        'description': 'description',
        'breakdowns': 'breakdowns',
        'affected_views_per_hour_on_open': 'affected_views_per_hour_on_open',
        'affected_views_per_hour': 'affected_views_per_hour',
        'affected_views': 'affected_views'
    }

    def __init__(self, threshold=None, status=None, started_at=None, severity=None, sample_size_unit=None, sample_size=None, resolved_at=None, notifications=None, notification_rules=None, measurement=None, measured_value_on_close=None, measured_value=None, incident_key=None, impact=None, id=None, error_description=None, description=None, breakdowns=None, affected_views_per_hour_on_open=None, affected_views_per_hour=None, affected_views=None, local_vars_configuration=None):  # noqa: E501
        """Incident - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default_copy()
        self.local_vars_configuration = local_vars_configuration

        self._threshold = None
        self._status = None
        self._started_at = None
        self._severity = None
        self._sample_size_unit = None
        self._sample_size = None
        self._resolved_at = None
        self._notifications = None
        self._notification_rules = None
        self._measurement = None
        self._measured_value_on_close = None
        self._measured_value = None
        self._incident_key = None
        self._impact = None
        self._id = None
        self._error_description = None
        self._description = None
        self._breakdowns = None
        self._affected_views_per_hour_on_open = None
        self._affected_views_per_hour = None
        self._affected_views = None
        self.discriminator = None

        if threshold is not None:
            self.threshold = threshold
        if status is not None:
            self.status = status
        if started_at is not None:
            self.started_at = started_at
        if severity is not None:
            self.severity = severity
        if sample_size_unit is not None:
            self.sample_size_unit = sample_size_unit
        if sample_size is not None:
            self.sample_size = sample_size
        if resolved_at is not None:
            self.resolved_at = resolved_at
        if notifications is not None:
            self.notifications = notifications
        if notification_rules is not None:
            self.notification_rules = notification_rules
        if measurement is not None:
            self.measurement = measurement
        if measured_value_on_close is not None:
            self.measured_value_on_close = measured_value_on_close
        if measured_value is not None:
            self.measured_value = measured_value
        if incident_key is not None:
            self.incident_key = incident_key
        if impact is not None:
            self.impact = impact
        if id is not None:
            self.id = id
        if error_description is not None:
            self.error_description = error_description
        if description is not None:
            self.description = description
        if breakdowns is not None:
            self.breakdowns = breakdowns
        if affected_views_per_hour_on_open is not None:
            self.affected_views_per_hour_on_open = affected_views_per_hour_on_open
        if affected_views_per_hour is not None:
            self.affected_views_per_hour = affected_views_per_hour
        if affected_views is not None:
            self.affected_views = affected_views

    @property
    def threshold(self):
        """Gets the threshold of this Incident.  # noqa: E501


        :return: The threshold of this Incident.  # noqa: E501
        :rtype: float
        """
        return self._threshold

    @threshold.setter
    def threshold(self, threshold):
        """Sets the threshold of this Incident.


        :param threshold: The threshold of this Incident.  # noqa: E501
        :type threshold: float
        """

        self._threshold = threshold

    @property
    def status(self):
        """Gets the status of this Incident.  # noqa: E501


        :return: The status of this Incident.  # noqa: E501
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this Incident.


        :param status: The status of this Incident.  # noqa: E501
        :type status: str
        """

        self._status = status

    @property
    def started_at(self):
        """Gets the started_at of this Incident.  # noqa: E501


        :return: The started_at of this Incident.  # noqa: E501
        :rtype: str
        """
        return self._started_at

    @started_at.setter
    def started_at(self, started_at):
        """Sets the started_at of this Incident.


        :param started_at: The started_at of this Incident.  # noqa: E501
        :type started_at: str
        """

        self._started_at = started_at

    @property
    def severity(self):
        """Gets the severity of this Incident.  # noqa: E501


        :return: The severity of this Incident.  # noqa: E501
        :rtype: str
        """
        return self._severity

    @severity.setter
    def severity(self, severity):
        """Sets the severity of this Incident.


        :param severity: The severity of this Incident.  # noqa: E501
        :type severity: str
        """

        self._severity = severity

    @property
    def sample_size_unit(self):
        """Gets the sample_size_unit of this Incident.  # noqa: E501


        :return: The sample_size_unit of this Incident.  # noqa: E501
        :rtype: str
        """
        return self._sample_size_unit

    @sample_size_unit.setter
    def sample_size_unit(self, sample_size_unit):
        """Sets the sample_size_unit of this Incident.


        :param sample_size_unit: The sample_size_unit of this Incident.  # noqa: E501
        :type sample_size_unit: str
        """

        self._sample_size_unit = sample_size_unit

    @property
    def sample_size(self):
        """Gets the sample_size of this Incident.  # noqa: E501


        :return: The sample_size of this Incident.  # noqa: E501
        :rtype: int
        """
        return self._sample_size

    @sample_size.setter
    def sample_size(self, sample_size):
        """Sets the sample_size of this Incident.


        :param sample_size: The sample_size of this Incident.  # noqa: E501
        :type sample_size: int
        """

        self._sample_size = sample_size

    @property
    def resolved_at(self):
        """Gets the resolved_at of this Incident.  # noqa: E501


        :return: The resolved_at of this Incident.  # noqa: E501
        :rtype: str
        """
        return self._resolved_at

    @resolved_at.setter
    def resolved_at(self, resolved_at):
        """Sets the resolved_at of this Incident.


        :param resolved_at: The resolved_at of this Incident.  # noqa: E501
        :type resolved_at: str
        """

        self._resolved_at = resolved_at

    @property
    def notifications(self):
        """Gets the notifications of this Incident.  # noqa: E501


        :return: The notifications of this Incident.  # noqa: E501
        :rtype: list[IncidentNotification]
        """
        return self._notifications

    @notifications.setter
    def notifications(self, notifications):
        """Sets the notifications of this Incident.


        :param notifications: The notifications of this Incident.  # noqa: E501
        :type notifications: list[IncidentNotification]
        """

        self._notifications = notifications

    @property
    def notification_rules(self):
        """Gets the notification_rules of this Incident.  # noqa: E501


        :return: The notification_rules of this Incident.  # noqa: E501
        :rtype: list[IncidentNotificationRule]
        """
        return self._notification_rules

    @notification_rules.setter
    def notification_rules(self, notification_rules):
        """Sets the notification_rules of this Incident.


        :param notification_rules: The notification_rules of this Incident.  # noqa: E501
        :type notification_rules: list[IncidentNotificationRule]
        """

        self._notification_rules = notification_rules

    @property
    def measurement(self):
        """Gets the measurement of this Incident.  # noqa: E501


        :return: The measurement of this Incident.  # noqa: E501
        :rtype: str
        """
        return self._measurement

    @measurement.setter
    def measurement(self, measurement):
        """Sets the measurement of this Incident.


        :param measurement: The measurement of this Incident.  # noqa: E501
        :type measurement: str
        """

        self._measurement = measurement

    @property
    def measured_value_on_close(self):
        """Gets the measured_value_on_close of this Incident.  # noqa: E501


        :return: The measured_value_on_close of this Incident.  # noqa: E501
        :rtype: float
        """
        return self._measured_value_on_close

    @measured_value_on_close.setter
    def measured_value_on_close(self, measured_value_on_close):
        """Sets the measured_value_on_close of this Incident.


        :param measured_value_on_close: The measured_value_on_close of this Incident.  # noqa: E501
        :type measured_value_on_close: float
        """

        self._measured_value_on_close = measured_value_on_close

    @property
    def measured_value(self):
        """Gets the measured_value of this Incident.  # noqa: E501


        :return: The measured_value of this Incident.  # noqa: E501
        :rtype: float
        """
        return self._measured_value

    @measured_value.setter
    def measured_value(self, measured_value):
        """Sets the measured_value of this Incident.


        :param measured_value: The measured_value of this Incident.  # noqa: E501
        :type measured_value: float
        """

        self._measured_value = measured_value

    @property
    def incident_key(self):
        """Gets the incident_key of this Incident.  # noqa: E501


        :return: The incident_key of this Incident.  # noqa: E501
        :rtype: str
        """
        return self._incident_key

    @incident_key.setter
    def incident_key(self, incident_key):
        """Sets the incident_key of this Incident.


        :param incident_key: The incident_key of this Incident.  # noqa: E501
        :type incident_key: str
        """

        self._incident_key = incident_key

    @property
    def impact(self):
        """Gets the impact of this Incident.  # noqa: E501


        :return: The impact of this Incident.  # noqa: E501
        :rtype: str
        """
        return self._impact

    @impact.setter
    def impact(self, impact):
        """Sets the impact of this Incident.


        :param impact: The impact of this Incident.  # noqa: E501
        :type impact: str
        """

        self._impact = impact

    @property
    def id(self):
        """Gets the id of this Incident.  # noqa: E501


        :return: The id of this Incident.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this Incident.


        :param id: The id of this Incident.  # noqa: E501
        :type id: str
        """

        self._id = id

    @property
    def error_description(self):
        """Gets the error_description of this Incident.  # noqa: E501


        :return: The error_description of this Incident.  # noqa: E501
        :rtype: str
        """
        return self._error_description

    @error_description.setter
    def error_description(self, error_description):
        """Sets the error_description of this Incident.


        :param error_description: The error_description of this Incident.  # noqa: E501
        :type error_description: str
        """

        self._error_description = error_description

    @property
    def description(self):
        """Gets the description of this Incident.  # noqa: E501


        :return: The description of this Incident.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this Incident.


        :param description: The description of this Incident.  # noqa: E501
        :type description: str
        """

        self._description = description

    @property
    def breakdowns(self):
        """Gets the breakdowns of this Incident.  # noqa: E501


        :return: The breakdowns of this Incident.  # noqa: E501
        :rtype: list[IncidentBreakdown]
        """
        return self._breakdowns

    @breakdowns.setter
    def breakdowns(self, breakdowns):
        """Sets the breakdowns of this Incident.


        :param breakdowns: The breakdowns of this Incident.  # noqa: E501
        :type breakdowns: list[IncidentBreakdown]
        """

        self._breakdowns = breakdowns

    @property
    def affected_views_per_hour_on_open(self):
        """Gets the affected_views_per_hour_on_open of this Incident.  # noqa: E501


        :return: The affected_views_per_hour_on_open of this Incident.  # noqa: E501
        :rtype: int
        """
        return self._affected_views_per_hour_on_open

    @affected_views_per_hour_on_open.setter
    def affected_views_per_hour_on_open(self, affected_views_per_hour_on_open):
        """Sets the affected_views_per_hour_on_open of this Incident.


        :param affected_views_per_hour_on_open: The affected_views_per_hour_on_open of this Incident.  # noqa: E501
        :type affected_views_per_hour_on_open: int
        """

        self._affected_views_per_hour_on_open = affected_views_per_hour_on_open

    @property
    def affected_views_per_hour(self):
        """Gets the affected_views_per_hour of this Incident.  # noqa: E501


        :return: The affected_views_per_hour of this Incident.  # noqa: E501
        :rtype: int
        """
        return self._affected_views_per_hour

    @affected_views_per_hour.setter
    def affected_views_per_hour(self, affected_views_per_hour):
        """Sets the affected_views_per_hour of this Incident.


        :param affected_views_per_hour: The affected_views_per_hour of this Incident.  # noqa: E501
        :type affected_views_per_hour: int
        """

        self._affected_views_per_hour = affected_views_per_hour

    @property
    def affected_views(self):
        """Gets the affected_views of this Incident.  # noqa: E501


        :return: The affected_views of this Incident.  # noqa: E501
        :rtype: int
        """
        return self._affected_views

    @affected_views.setter
    def affected_views(self, affected_views):
        """Sets the affected_views of this Incident.


        :param affected_views: The affected_views of this Incident.  # noqa: E501
        :type affected_views: int
        """

        self._affected_views = affected_views

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = inspect.getargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: convert(x),
                    value
                ))
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], convert(item[1])),
                    value.items()
                ))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Incident):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, Incident):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Mux API

    Mux is how developers build online video. This API encompasses both Mux Video and Mux Data functionality to help you build your video-related projects better and faster than ever before.  # noqa: E501

    The version of the OpenAPI document: v1
    Contact: devex@mux.com
    Generated by: https://openapi-generator.tech
"""


import inspect
import pprint
import re  # noqa: F401
import six

from mux_python.configuration import Configuration


class InputSettingsOverlaySettings(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'vertical_align': 'str',
        'vertical_margin': 'str',
        'horizontal_align': 'str',
        'horizontal_margin': 'str',
        'width': 'str',
        'height': 'str',
        'opacity': 'str'
    }

    attribute_map = {
        'vertical_align': 'vertical_align',
        'vertical_margin': 'vertical_margin',
        'horizontal_align': 'horizontal_align',
        'horizontal_margin': 'horizontal_margin',
        'width': 'width',
        'height': 'height',
        'opacity': 'opacity'
    }

    def __init__(self, vertical_align=None, vertical_margin=None, horizontal_align=None, horizontal_margin=None, width=None, height=None, opacity=None, local_vars_configuration=None):  # noqa: E501
        """InputSettingsOverlaySettings - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default_copy()
        self.local_vars_configuration = local_vars_configuration

        self._vertical_align = None
        self._vertical_margin = None
        self._horizontal_align = None
        self._horizontal_margin = None
        self._width = None
        self._height = None
        self._opacity = None
        self.discriminator = None

        if vertical_align is not None:
            self.vertical_align = vertical_align
        if vertical_margin is not None:
            self.vertical_margin = vertical_margin
        if horizontal_align is not None:
            self.horizontal_align = horizontal_align
        if horizontal_margin is not None:
            self.horizontal_margin = horizontal_margin
        if width is not None:
            self.width = width
        if height is not None:
            self.height = height
        if opacity is not None:
            self.opacity = opacity

    @property
    def vertical_align(self):
        """Gets the vertical_align of this InputSettingsOverlaySettings.  # noqa: E501

        Where the vertical positioning of the overlay/watermark should begin from. Defaults to `\"top\"`  # noqa: E501

        :return: The vertical_align of this InputSettingsOverlaySettings.  # noqa: E501
        :rtype: str
        """
        return self._vertical_align

    @vertical_align.setter
    def vertical_align(self, vertical_align):
        """Sets the vertical_align of this InputSettingsOverlaySettings.

        Where the vertical positioning of the overlay/watermark should begin from. Defaults to `\"top\"`  # noqa: E501

        :param vertical_align: The vertical_align of this InputSettingsOverlaySettings.  # noqa: E501
        :type vertical_align: str
        """
        allowed_values = ["top", "middle", "bottom"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and vertical_align not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `vertical_align` ({0}), must be one of {1}"  # noqa: E501
                .format(vertical_align, allowed_values)
            )

        self._vertical_align = vertical_align

    @property
    def vertical_margin(self):
        """Gets the vertical_margin of this InputSettingsOverlaySettings.  # noqa: E501

        The distance from the vertical_align starting point and the image's closest edge. Can be expressed as a percent (\"10%\") or as a pixel value (\"100px\"). Negative values will move the overlay offscreen. In the case of 'middle', a positive value will shift the overlay towards the bottom and and a negative value will shift it towards the top.  # noqa: E501

        :return: The vertical_margin of this InputSettingsOverlaySettings.  # noqa: E501
        :rtype: str
        """
        return self._vertical_margin

    @vertical_margin.setter
    def vertical_margin(self, vertical_margin):
        """Sets the vertical_margin of this InputSettingsOverlaySettings.

        The distance from the vertical_align starting point and the image's closest edge. Can be expressed as a percent (\"10%\") or as a pixel value (\"100px\"). Negative values will move the overlay offscreen. In the case of 'middle', a positive value will shift the overlay towards the bottom and and a negative value will shift it towards the top.  # noqa: E501

        :param vertical_margin: The vertical_margin of this InputSettingsOverlaySettings.  # noqa: E501
        :type vertical_margin: str
        """

        self._vertical_margin = vertical_margin

    @property
    def horizontal_align(self):
        """Gets the horizontal_align of this InputSettingsOverlaySettings.  # noqa: E501

        Where the horizontal positioning of the overlay/watermark should begin from.  # noqa: E501

        :return: The horizontal_align of this InputSettingsOverlaySettings.  # noqa: E501
        :rtype: str
        """
        return self._horizontal_align

    @horizontal_align.setter
    def horizontal_align(self, horizontal_align):
        """Sets the horizontal_align of this InputSettingsOverlaySettings.

        Where the horizontal positioning of the overlay/watermark should begin from.  # noqa: E501

        :param horizontal_align: The horizontal_align of this InputSettingsOverlaySettings.  # noqa: E501
        :type horizontal_align: str
        """
        allowed_values = ["left", "center", "right"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and horizontal_align not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `horizontal_align` ({0}), must be one of {1}"  # noqa: E501
                .format(horizontal_align, allowed_values)
            )

        self._horizontal_align = horizontal_align

    @property
    def horizontal_margin(self):
        """Gets the horizontal_margin of this InputSettingsOverlaySettings.  # noqa: E501

        The distance from the horizontal_align starting point and the image's closest edge. Can be expressed as a percent (\"10%\") or as a pixel value (\"100px\"). Negative values will move the overlay offscreen. In the case of 'center', a positive value will shift the image towards the right and and a negative value will shift it towards the left.  # noqa: E501

        :return: The horizontal_margin of this InputSettingsOverlaySettings.  # noqa: E501
        :rtype: str
        """
        return self._horizontal_margin

    @horizontal_margin.setter
    def horizontal_margin(self, horizontal_margin):
        """Sets the horizontal_margin of this InputSettingsOverlaySettings.

        The distance from the horizontal_align starting point and the image's closest edge. Can be expressed as a percent (\"10%\") or as a pixel value (\"100px\"). Negative values will move the overlay offscreen. In the case of 'center', a positive value will shift the image towards the right and and a negative value will shift it towards the left.  # noqa: E501

        :param horizontal_margin: The horizontal_margin of this InputSettingsOverlaySettings.  # noqa: E501
        :type horizontal_margin: str
        """

        self._horizontal_margin = horizontal_margin

    @property
    def width(self):
        """Gets the width of this InputSettingsOverlaySettings.  # noqa: E501

        How wide the overlay should appear. Can be expressed as a percent (\"10%\") or as a pixel value (\"100px\"). If both width and height are left blank the width will be the true pixels of the image, applied as if the video has been scaled to fit a 1920x1080 frame. If height is supplied with no width, the width will scale proportionally to the height.  # noqa: E501

        :return: The width of this InputSettingsOverlaySettings.  # noqa: E501
        :rtype: str
        """
        return self._width

    @width.setter
    def width(self, width):
        """Sets the width of this InputSettingsOverlaySettings.

        How wide the overlay should appear. Can be expressed as a percent (\"10%\") or as a pixel value (\"100px\"). If both width and height are left blank the width will be the true pixels of the image, applied as if the video has been scaled to fit a 1920x1080 frame. If height is supplied with no width, the width will scale proportionally to the height.  # noqa: E501

        :param width: The width of this InputSettingsOverlaySettings.  # noqa: E501
        :type width: str
        """

        self._width = width

    @property
    def height(self):
        """Gets the height of this InputSettingsOverlaySettings.  # noqa: E501

        How tall the overlay should appear. Can be expressed as a percent (\"10%\") or as a pixel value (\"100px\"). If both width and height are left blank the height will be the true pixels of the image, applied as if the video has been scaled to fit a 1920x1080 frame. If width is supplied with no height, the height will scale proportionally to the width.  # noqa: E501

        :return: The height of this InputSettingsOverlaySettings.  # noqa: E501
        :rtype: str
        """
        return self._height

    @height.setter
    def height(self, height):
        """Sets the height of this InputSettingsOverlaySettings.

        How tall the overlay should appear. Can be expressed as a percent (\"10%\") or as a pixel value (\"100px\"). If both width and height are left blank the height will be the true pixels of the image, applied as if the video has been scaled to fit a 1920x1080 frame. If width is supplied with no height, the height will scale proportionally to the width.  # noqa: E501

        :param height: The height of this InputSettingsOverlaySettings.  # noqa: E501
        :type height: str
        """

        self._height = height

    @property
    def opacity(self):
        """Gets the opacity of this InputSettingsOverlaySettings.  # noqa: E501

        How opaque the overlay should appear, expressed as a percent. (Default 100%)  # noqa: E501

        :return: The opacity of this InputSettingsOverlaySettings.  # noqa: E501
        :rtype: str
        """
        return self._opacity

    @opacity.setter
    def opacity(self, opacity):
        """Sets the opacity of this InputSettingsOverlaySettings.

        How opaque the overlay should appear, expressed as a percent. (Default 100%)  # noqa: E501

        :param opacity: The opacity of this InputSettingsOverlaySettings.  # noqa: E501
        :type opacity: str
        """

        self._opacity = opacity

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = inspect.getargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: convert(x),
                    value
                ))
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], convert(item[1])),
                    value.items()
                ))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, InputSettingsOverlaySettings):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, InputSettingsOverlaySettings):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
Mux Python - Copyright 2019 Mux Inc.

NOTE: This class is auto generated. Do not edit the class manually.
"""


from __future__ import absolute_import

import unittest

import mux_python
from mux_python.api.real_time_api import RealTimeApi  # noqa: E501
from mux_python.rest import ApiException


class TestRealTimeApi(unittest.TestCase):
    """RealTimeApi unit test stubs"""

    def setUp(self):
        self.api = mux_python.api.real_time_api.RealTimeApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_get_realtime_breakdown(self):
        """Test case for get_realtime_breakdown

        Get Real-Time Breakdown  # noqa: E501
        """
        pass

    def test_get_realtime_histogram_timeseries(self):
        """Test case for get_realtime_histogram_timeseries

        Get Real-Time Histogram Timeseries  # noqa: E501
        """
        pass

    def test_get_realtime_timeseries(self):
        """Test case for get_realtime_timeseries

        Get Real-Time Timeseries  # noqa: E501
        """
        pass

    def test_list_realtime_dimensions(self):
        """Test case for list_realtime_dimensions

        List Real-Time Dimensions  # noqa: E501
        """
        pass

    def test_list_realtime_metrics(self):
        """Test case for list_realtime_metrics

        List Real-Time Metrics  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
